==> 1.0.13.tar.gz: lib/src/core/widgets/pickers/ModernFormDateRangePicker.dart <==
part of modern_form_core;

class ModernFormDateRangePicker extends StatelessWidget {
  final String? label;
  final String? helperText;
  final Icon? prefixIcon;
  final DateTimeRange? value;
  final void Function(DateTimeRange selecteds)? onSelected;
  final bool? sufixCloseEnabled;
  final bool? enabled;
  final String? Function(dynamic)? validator;

  const ModernFormDateRangePicker({
    Key? key,
    this.label,
    this.value,
    this.prefixIcon,
    this.onSelected,
    this.sufixCloseEnabled = true,
    this.enabled,
    this.validator,
    this.helperText,
  });

  @override
  Widget build(BuildContext context) {
    return ModernFormFakeTextField(
      label: label ?? "",
      helperText: helperText,
      validator: validator,
      initialValue: value != null ? formatDate(value) : null,
      sufixIconEnabled: sufixCloseEnabled != null && sufixCloseEnabled!,
      enabled: enabled ?? true,
      onTap: () async {
        DateTimeRange? picked = await showDateRangePicker(
          context: context,
          initialDateRange: value ??
              DateTimeRange(
                start: DateTime.now(),
                end: DateTime.now().add(Duration(days: 7)),
              ),
          firstDate: DateTime(2020, 01, 01, 00, 00),
          lastDate: DateTime.now().add(Duration(days: 1825)),
          saveText: "Selecionar",
          helpText: "Selecionar intervalo",
          locale: Locale('pt', "BR"),
        );

        if (picked != null && onSelected != null) {
          onSelected!(picked);
        }
      },
    );
  }

  String formatDate(DateTimeRange? period) {
    String periodFormated = "";

    if (period != null) {
      periodFormated = ModernFormUtils.dateFormat.format(period.start);
    }

    if (period != null && period.end != DateTime(0, 0, 0)) {
      periodFormated += " - ${ModernFormUtils.dateFormat.format(period.end)}";
    }

    return periodFormated;
  }
}

==> 1.17.1.tar.gz: lib/src/core/widgets/pickers/ModernFormDateRangePicker.dart <==
part of modern_form_core;

class ModernFormDateRangePicker extends StatelessWidget {
  final String? label;
  final String? helperText;
  final Icon? prefixIcon;
  final DateTimeRange? value;
  final void Function(DateTimeRange selecteds)? onSelected;
  final void Function()? onRemove;
  final bool sufixCloseEnabled;
  final bool? enabled;
  final String? Function(dynamic)? validator;

  const ModernFormDateRangePicker({
    Key? key,
    this.label,
    this.value,
    this.prefixIcon,
    this.onSelected,
    this.onRemove,
    this.sufixCloseEnabled = true,
    this.enabled,
    this.validator,
    this.helperText,
  });

  @override
  Widget build(BuildContext context) {
    return ModernFormFakeTextField(
      label: label ?? "",
      helperText: helperText,
      validator: validator,
      initialValue: value != null ? formatDate(value) : null,
      sufixIconEnabled: sufixCloseEnabled,
      enabled: enabled ?? true,
      onChanged: onRemove != null
          ? (v) {
              onRemove!();
            }
          : null,
      onTap: () async {
        DateTimeRange? picked = await showDateRangePicker(
          context: context,
          initialDateRange: value ??
              DateTimeRange(
                start: DateTime.now(),
                end: DateTime.now().add(Duration(days: 7)),
              ),
          firstDate: DateTime(2020, 01, 01, 00, 00),
          lastDate: DateTime.now().add(Duration(days: 1825)),
          saveText: "Selecionar",
          helpText: "Selecionar intervalo",
          locale: Locale('pt', "BR"),
        );

        if (picked != null && onSelected != null) {
          onSelected!(picked);
        }
      },
    );
  }

  String formatDate(DateTimeRange? period) {
    String periodFormated = "";

    if (period != null) {
      periodFormated = ModernFormUtils.dateFormat.format(period.start);
    }

    if (period != null && period.end != DateTime(0, 0, 0)) {
      periodFormated += " - ${ModernFormUtils.dateFormat.format(period.end)}";
    }

    return periodFormated;
  }
}
